# -*- coding: utf-8 -*-
#
# Copyright Grégory Soutadé 2023

# This file is part of iwla

# iwla is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# iwla is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with iwla.  If not, see <http://www.gnu.org/licenses/>.
#

from iwla import IWLA
from iplugin import IPlugin
from display import *

"""
Display hook

Add IPv4/IPv6 statistics

Plugin requirements :
    post_analysis/ip_type

Conf values needed :
    None

Output files :
    OUTPUT_ROOT/year/month/index.html

Statistics creation :
    None

Statistics update :
    None

Statistics deletion :
    None
"""

class IWLADisplayIPType(IPlugin):
    def __init__(self, iwla):
        super(IWLADisplayIPType, self).__init__(iwla)
        self.requires = ['IWLAPostAnalysisIPType']

    def hook(self):
        display = self.iwla.getDisplay()
        ip_types = self.iwla.getMonthStats()['ip_type']

        # Subdomains in index
        title = self.iwla._(u'IP types')

        index = self.iwla.getDisplayIndex()
        
        table = display.createBlock(DisplayHTMLBlockTable, title, [self.iwla._('Type'), self.iwla._(u'Entrance')])
        table.setColsCSSClass(['', 'iwla_hit'])
        types = sorted(ip_types.items(), key=lambda t: t[0])
        for (_type, count) in types:
            table.appendRow([_type, count])
        table.computeRatio(1)
        index.appendBlock(table)
